# Autogenerated by nbdev

d = { 'settings': { 'branch': 'master',
                'doc_baseurl': '/',
                'doc_host': 'https://fastmonai.no',
                'git_url': 'https://github.com/MMIV-ML/fastMONAI',
                'lib_path': 'fastMONAI'},
  'syms': { 'fastMONAI.dataset_info': { 'fastMONAI.dataset_info.MedDataset': ('dataset_info.html#meddataset', 'fastMONAI/dataset_info.py'),
                                        'fastMONAI.dataset_info.MedDataset.__init__': ( 'dataset_info.html#meddataset.__init__',
                                                                                        'fastMONAI/dataset_info.py'),
                                        'fastMONAI.dataset_info.MedDataset._create_data_frame': ( 'dataset_info.html#meddataset._create_data_frame',
                                                                                                  'fastMONAI/dataset_info.py'),
                                        'fastMONAI.dataset_info.MedDataset._get_data_info': ( 'dataset_info.html#meddataset._get_data_info',
                                                                                              'fastMONAI/dataset_info.py'),
                                        'fastMONAI.dataset_info.MedDataset.get_largest_img_size': ( 'dataset_info.html#meddataset.get_largest_img_size',
                                                                                                    'fastMONAI/dataset_info.py'),
                                        'fastMONAI.dataset_info.MedDataset.suggestion': ( 'dataset_info.html#meddataset.suggestion',
                                                                                          'fastMONAI/dataset_info.py'),
                                        'fastMONAI.dataset_info.MedDataset.summary': ( 'dataset_info.html#meddataset.summary',
                                                                                       'fastMONAI/dataset_info.py'),
                                        'fastMONAI.dataset_info.get_class_weights': ( 'dataset_info.html#get_class_weights',
                                                                                      'fastMONAI/dataset_info.py')},
            'fastMONAI.external_data': { 'fastMONAI.external_data.MURLs': ('external_data.html#murls', 'fastMONAI/external_data.py'),
                                         'fastMONAI.external_data._create_nodule_df': ( 'external_data.html#_create_nodule_df',
                                                                                        'fastMONAI/external_data.py'),
                                         'fastMONAI.external_data._create_spine_df': ( 'external_data.html#_create_spine_df',
                                                                                       'fastMONAI/external_data.py'),
                                         'fastMONAI.external_data._dataset_available_locally': ( 'external_data.html#_dataset_available_locally',
                                                                                                 'fastMONAI/external_data.py'),
                                         'fastMONAI.external_data._df_sort_and_add_columns': ( 'external_data.html#_df_sort_and_add_columns',
                                                                                               'fastMONAI/external_data.py'),
                                         'fastMONAI.external_data._process_ixi_xls': ( 'external_data.html#_process_ixi_xls',
                                                                                       'fastMONAI/external_data.py'),
                                         'fastMONAI.external_data._process_medmnist_img': ( 'external_data.html#_process_medmnist_img',
                                                                                            'fastMONAI/external_data.py'),
                                         'fastMONAI.external_data.download_example_endometrial_cancer_data': ( 'external_data.html#download_example_endometrial_cancer_data',
                                                                                                               'fastMONAI/external_data.py'),
                                         'fastMONAI.external_data.download_example_spine_data': ( 'external_data.html#download_example_spine_data',
                                                                                                  'fastMONAI/external_data.py'),
                                         'fastMONAI.external_data.download_ixi_data': ( 'external_data.html#download_ixi_data',
                                                                                        'fastMONAI/external_data.py'),
                                         'fastMONAI.external_data.download_ixi_tiny': ( 'external_data.html#download_ixi_tiny',
                                                                                        'fastMONAI/external_data.py'),
                                         'fastMONAI.external_data.download_medmnist3d_dataset': ( 'external_data.html#download_medmnist3d_dataset',
                                                                                                  'fastMONAI/external_data.py'),
                                         'fastMONAI.external_data.download_spine_test_data': ( 'external_data.html#download_spine_test_data',
                                                                                               'fastMONAI/external_data.py')},
            'fastMONAI.research_utils': { 'fastMONAI.research_utils.pred_postprocess': ( 'research_utils.html#pred_postprocess',
                                                                                         'fastMONAI/research_utils.py')},
            'fastMONAI.utils': { 'fastMONAI.utils.load_variables': ('utils.html#load_variables', 'fastMONAI/utils.py'),
                                 'fastMONAI.utils.print_colab_gpu_info': ('utils.html#print_colab_gpu_info', 'fastMONAI/utils.py'),
                                 'fastMONAI.utils.store_variables': ('utils.html#store_variables', 'fastMONAI/utils.py')},
            'fastMONAI.vision_all': {},
            'fastMONAI.vision_augmentation': { 'fastMONAI.vision_augmentation.BinaryConverter': ( 'vision_augment.html#binaryconverter',
                                                                                                  'fastMONAI/vision_augmentation.py'),
                                               'fastMONAI.vision_augmentation.BinaryConverter.encodes': ( 'vision_augment.html#binaryconverter.encodes',
                                                                                                          'fastMONAI/vision_augmentation.py'),
                                               'fastMONAI.vision_augmentation.BraTSMaskConverter': ( 'vision_augment.html#bratsmaskconverter',
                                                                                                     'fastMONAI/vision_augmentation.py'),
                                               'fastMONAI.vision_augmentation.BraTSMaskConverter.encodes': ( 'vision_augment.html#bratsmaskconverter.encodes',
                                                                                                             'fastMONAI/vision_augmentation.py'),
                                               'fastMONAI.vision_augmentation.CustomDictTransform': ( 'vision_augment.html#customdicttransform',
                                                                                                      'fastMONAI/vision_augmentation.py'),
                                               'fastMONAI.vision_augmentation.CustomDictTransform.__init__': ( 'vision_augment.html#customdicttransform.__init__',
                                                                                                               'fastMONAI/vision_augmentation.py'),
                                               'fastMONAI.vision_augmentation.CustomDictTransform.encodes': ( 'vision_augment.html#customdicttransform.encodes',
                                                                                                              'fastMONAI/vision_augmentation.py'),
                                               'fastMONAI.vision_augmentation.OneOf': ( 'vision_augment.html#oneof',
                                                                                        'fastMONAI/vision_augmentation.py'),
                                               'fastMONAI.vision_augmentation.OneOf.__init__': ( 'vision_augment.html#oneof.__init__',
                                                                                                 'fastMONAI/vision_augmentation.py'),
                                               'fastMONAI.vision_augmentation.PadOrCrop': ( 'vision_augment.html#padorcrop',
                                                                                            'fastMONAI/vision_augmentation.py'),
                                               'fastMONAI.vision_augmentation.PadOrCrop.__init__': ( 'vision_augment.html#padorcrop.__init__',
                                                                                                     'fastMONAI/vision_augmentation.py'),
                                               'fastMONAI.vision_augmentation.PadOrCrop.encodes': ( 'vision_augment.html#padorcrop.encodes',
                                                                                                    'fastMONAI/vision_augmentation.py'),
                                               'fastMONAI.vision_augmentation.RandomAffine': ( 'vision_augment.html#randomaffine',
                                                                                               'fastMONAI/vision_augmentation.py'),
                                               'fastMONAI.vision_augmentation.RandomAffine.__init__': ( 'vision_augment.html#randomaffine.__init__',
                                                                                                        'fastMONAI/vision_augmentation.py'),
                                               'fastMONAI.vision_augmentation.RandomBiasField': ( 'vision_augment.html#randombiasfield',
                                                                                                  'fastMONAI/vision_augmentation.py'),
                                               'fastMONAI.vision_augmentation.RandomBiasField.__init__': ( 'vision_augment.html#randombiasfield.__init__',
                                                                                                           'fastMONAI/vision_augmentation.py'),
                                               'fastMONAI.vision_augmentation.RandomBiasField.encodes': ( 'vision_augment.html#randombiasfield.encodes',
                                                                                                          'fastMONAI/vision_augmentation.py'),
                                               'fastMONAI.vision_augmentation.RandomBlur': ( 'vision_augment.html#randomblur',
                                                                                             'fastMONAI/vision_augmentation.py'),
                                               'fastMONAI.vision_augmentation.RandomBlur.__init__': ( 'vision_augment.html#randomblur.__init__',
                                                                                                      'fastMONAI/vision_augmentation.py'),
                                               'fastMONAI.vision_augmentation.RandomBlur.encodes': ( 'vision_augment.html#randomblur.encodes',
                                                                                                     'fastMONAI/vision_augmentation.py'),
                                               'fastMONAI.vision_augmentation.RandomElasticDeformation': ( 'vision_augment.html#randomelasticdeformation',
                                                                                                           'fastMONAI/vision_augmentation.py'),
                                               'fastMONAI.vision_augmentation.RandomElasticDeformation.__init__': ( 'vision_augment.html#randomelasticdeformation.__init__',
                                                                                                                    'fastMONAI/vision_augmentation.py'),
                                               'fastMONAI.vision_augmentation.RandomFlip': ( 'vision_augment.html#randomflip',
                                                                                             'fastMONAI/vision_augmentation.py'),
                                               'fastMONAI.vision_augmentation.RandomFlip.__init__': ( 'vision_augment.html#randomflip.__init__',
                                                                                                      'fastMONAI/vision_augmentation.py'),
                                               'fastMONAI.vision_augmentation.RandomGamma': ( 'vision_augment.html#randomgamma',
                                                                                              'fastMONAI/vision_augmentation.py'),
                                               'fastMONAI.vision_augmentation.RandomGamma.__init__': ( 'vision_augment.html#randomgamma.__init__',
                                                                                                       'fastMONAI/vision_augmentation.py'),
                                               'fastMONAI.vision_augmentation.RandomGamma.encodes': ( 'vision_augment.html#randomgamma.encodes',
                                                                                                      'fastMONAI/vision_augmentation.py'),
                                               'fastMONAI.vision_augmentation.RandomGhosting': ( 'vision_augment.html#randomghosting',
                                                                                                 'fastMONAI/vision_augmentation.py'),
                                               'fastMONAI.vision_augmentation.RandomGhosting.__init__': ( 'vision_augment.html#randomghosting.__init__',
                                                                                                          'fastMONAI/vision_augmentation.py'),
                                               'fastMONAI.vision_augmentation.RandomGhosting.encodes': ( 'vision_augment.html#randomghosting.encodes',
                                                                                                         'fastMONAI/vision_augmentation.py'),
                                               'fastMONAI.vision_augmentation.RandomMotion': ( 'vision_augment.html#randommotion',
                                                                                               'fastMONAI/vision_augmentation.py'),
                                               'fastMONAI.vision_augmentation.RandomMotion.__init__': ( 'vision_augment.html#randommotion.__init__',
                                                                                                        'fastMONAI/vision_augmentation.py'),
                                               'fastMONAI.vision_augmentation.RandomMotion.encodes': ( 'vision_augment.html#randommotion.encodes',
                                                                                                       'fastMONAI/vision_augmentation.py'),
                                               'fastMONAI.vision_augmentation.RandomNoise': ( 'vision_augment.html#randomnoise',
                                                                                              'fastMONAI/vision_augmentation.py'),
                                               'fastMONAI.vision_augmentation.RandomNoise.__init__': ( 'vision_augment.html#randomnoise.__init__',
                                                                                                       'fastMONAI/vision_augmentation.py'),
                                               'fastMONAI.vision_augmentation.RandomNoise.encodes': ( 'vision_augment.html#randomnoise.encodes',
                                                                                                      'fastMONAI/vision_augmentation.py'),
                                               'fastMONAI.vision_augmentation.RandomSpike': ( 'vision_augment.html#randomspike',
                                                                                              'fastMONAI/vision_augmentation.py'),
                                               'fastMONAI.vision_augmentation.RandomSpike.__init__': ( 'vision_augment.html#randomspike.__init__',
                                                                                                       'fastMONAI/vision_augmentation.py'),
                                               'fastMONAI.vision_augmentation.RandomSpike.encodes': ( 'vision_augment.html#randomspike.encodes',
                                                                                                      'fastMONAI/vision_augmentation.py'),
                                               'fastMONAI.vision_augmentation.ZNormalization': ( 'vision_augment.html#znormalization',
                                                                                                 'fastMONAI/vision_augmentation.py'),
                                               'fastMONAI.vision_augmentation.ZNormalization.__init__': ( 'vision_augment.html#znormalization.__init__',
                                                                                                          'fastMONAI/vision_augmentation.py'),
                                               'fastMONAI.vision_augmentation.ZNormalization.encodes': ( 'vision_augment.html#znormalization.encodes',
                                                                                                         'fastMONAI/vision_augmentation.py'),
                                               'fastMONAI.vision_augmentation.do_pad_or_crop': ( 'vision_augment.html#do_pad_or_crop',
                                                                                                 'fastMONAI/vision_augmentation.py')},
            'fastMONAI.vision_core': { 'fastMONAI.vision_core.MedBase': ('vision_core.html#medbase', 'fastMONAI/vision_core.py'),
                                       'fastMONAI.vision_core.MedBase.__repr__': ( 'vision_core.html#medbase.__repr__',
                                                                                   'fastMONAI/vision_core.py'),
                                       'fastMONAI.vision_core.MedBase.create': ( 'vision_core.html#medbase.create',
                                                                                 'fastMONAI/vision_core.py'),
                                       'fastMONAI.vision_core.MedBase.item_preprocessing': ( 'vision_core.html#medbase.item_preprocessing',
                                                                                             'fastMONAI/vision_core.py'),
                                       'fastMONAI.vision_core.MedBase.show': ('vision_core.html#medbase.show', 'fastMONAI/vision_core.py'),
                                       'fastMONAI.vision_core.MedImage': ('vision_core.html#medimage', 'fastMONAI/vision_core.py'),
                                       'fastMONAI.vision_core.MedMask': ('vision_core.html#medmask', 'fastMONAI/vision_core.py'),
                                       'fastMONAI.vision_core.MetaResolver': ('vision_core.html#metaresolver', 'fastMONAI/vision_core.py'),
                                       'fastMONAI.vision_core._load_and_preprocess': ( 'vision_core.html#_load_and_preprocess',
                                                                                       'fastMONAI/vision_core.py'),
                                       'fastMONAI.vision_core._multi_channel': ( 'vision_core.html#_multi_channel',
                                                                                 'fastMONAI/vision_core.py'),
                                       'fastMONAI.vision_core._preprocess': ('vision_core.html#_preprocess', 'fastMONAI/vision_core.py'),
                                       'fastMONAI.vision_core.med_img_reader': ( 'vision_core.html#med_img_reader',
                                                                                 'fastMONAI/vision_core.py')},
            'fastMONAI.vision_data': { 'fastMONAI.vision_data.MedDataBlock': ('vision_data.html#meddatablock', 'fastMONAI/vision_data.py'),
                                       'fastMONAI.vision_data.MedDataBlock.__init__': ( 'vision_data.html#meddatablock.__init__',
                                                                                        'fastMONAI/vision_data.py'),
                                       'fastMONAI.vision_data.MedImageDataLoaders': ( 'vision_data.html#medimagedataloaders',
                                                                                      'fastMONAI/vision_data.py'),
                                       'fastMONAI.vision_data.MedImageDataLoaders.from_df': ( 'vision_data.html#medimagedataloaders.from_df',
                                                                                              'fastMONAI/vision_data.py'),
                                       'fastMONAI.vision_data.MedMaskBlock': ('vision_data.html#medmaskblock', 'fastMONAI/vision_data.py'),
                                       'fastMONAI.vision_data.batch_pred_to_multiclass_mask': ( 'vision_data.html#batch_pred_to_multiclass_mask',
                                                                                                'fastMONAI/vision_data.py'),
                                       'fastMONAI.vision_data.plot_top_losses': ( 'vision_data.html#plot_top_losses',
                                                                                  'fastMONAI/vision_data.py'),
                                       'fastMONAI.vision_data.pred_to_binary_mask': ( 'vision_data.html#pred_to_binary_mask',
                                                                                      'fastMONAI/vision_data.py'),
                                       'fastMONAI.vision_data.pred_to_multiclass_mask': ( 'vision_data.html#pred_to_multiclass_mask',
                                                                                          'fastMONAI/vision_data.py'),
                                       'fastMONAI.vision_data.show_batch': ('vision_data.html#show_batch', 'fastMONAI/vision_data.py'),
                                       'fastMONAI.vision_data.show_results': ('vision_data.html#show_results', 'fastMONAI/vision_data.py')},
            'fastMONAI.vision_inference': { 'fastMONAI.vision_inference._do_resize': ( 'vision_inference.html#_do_resize',
                                                                                       'fastMONAI/vision_inference.py'),
                                            'fastMONAI.vision_inference._to_original_orientation': ( 'vision_inference.html#_to_original_orientation',
                                                                                                     'fastMONAI/vision_inference.py'),
                                            'fastMONAI.vision_inference._update_uid': ( 'vision_inference.html#_update_uid',
                                                                                        'fastMONAI/vision_inference.py'),
                                            'fastMONAI.vision_inference.compute_binary_tumor_volume': ( 'vision_inference.html#compute_binary_tumor_volume',
                                                                                                        'fastMONAI/vision_inference.py'),
                                            'fastMONAI.vision_inference.gradio_image_classifier': ( 'vision_inference.html#gradio_image_classifier',
                                                                                                    'fastMONAI/vision_inference.py'),
                                            'fastMONAI.vision_inference.inference': ( 'vision_inference.html#inference',
                                                                                      'fastMONAI/vision_inference.py'),
                                            'fastMONAI.vision_inference.load_system_resources': ( 'vision_inference.html#load_system_resources',
                                                                                                  'fastMONAI/vision_inference.py'),
                                            'fastMONAI.vision_inference.refine_binary_pred_mask': ( 'vision_inference.html#refine_binary_pred_mask',
                                                                                                    'fastMONAI/vision_inference.py'),
                                            'fastMONAI.vision_inference.save_series_pred': ( 'vision_inference.html#save_series_pred',
                                                                                             'fastMONAI/vision_inference.py')},
            'fastMONAI.vision_loss': { 'fastMONAI.vision_loss.CustomLoss': ( 'vision_loss_functions.html#customloss',
                                                                             'fastMONAI/vision_loss.py'),
                                       'fastMONAI.vision_loss.CustomLoss.__call__': ( 'vision_loss_functions.html#customloss.__call__',
                                                                                      'fastMONAI/vision_loss.py'),
                                       'fastMONAI.vision_loss.CustomLoss.__init__': ( 'vision_loss_functions.html#customloss.__init__',
                                                                                      'fastMONAI/vision_loss.py'),
                                       'fastMONAI.vision_loss.CustomLoss.activation': ( 'vision_loss_functions.html#customloss.activation',
                                                                                        'fastMONAI/vision_loss.py'),
                                       'fastMONAI.vision_loss.CustomLoss.decodes': ( 'vision_loss_functions.html#customloss.decodes',
                                                                                     'fastMONAI/vision_loss.py'),
                                       'fastMONAI.vision_loss.TverskyFocalLoss': ( 'vision_loss_functions.html#tverskyfocalloss',
                                                                                   'fastMONAI/vision_loss.py'),
                                       'fastMONAI.vision_loss.TverskyFocalLoss.__init__': ( 'vision_loss_functions.html#tverskyfocalloss.__init__',
                                                                                            'fastMONAI/vision_loss.py'),
                                       'fastMONAI.vision_loss.TverskyFocalLoss.forward': ( 'vision_loss_functions.html#tverskyfocalloss.forward',
                                                                                           'fastMONAI/vision_loss.py')},
            'fastMONAI.vision_metrics': { 'fastMONAI.vision_metrics.binary_dice_score': ( 'vision_metrics.html#binary_dice_score',
                                                                                          'fastMONAI/vision_metrics.py'),
                                          'fastMONAI.vision_metrics.binary_hausdorff_distance': ( 'vision_metrics.html#binary_hausdorff_distance',
                                                                                                  'fastMONAI/vision_metrics.py'),
                                          'fastMONAI.vision_metrics.calculate_dsc': ( 'vision_metrics.html#calculate_dsc',
                                                                                      'fastMONAI/vision_metrics.py'),
                                          'fastMONAI.vision_metrics.calculate_haus': ( 'vision_metrics.html#calculate_haus',
                                                                                       'fastMONAI/vision_metrics.py'),
                                          'fastMONAI.vision_metrics.multi_dice_score': ( 'vision_metrics.html#multi_dice_score',
                                                                                         'fastMONAI/vision_metrics.py'),
                                          'fastMONAI.vision_metrics.multi_hausdorff_distance': ( 'vision_metrics.html#multi_hausdorff_distance',
                                                                                                 'fastMONAI/vision_metrics.py')},
            'fastMONAI.vision_plot': { 'fastMONAI.vision_plot._get_slice': ('vision_plot.html#_get_slice', 'fastMONAI/vision_plot.py'),
                                       'fastMONAI.vision_plot.find_max_slice': ( 'vision_plot.html#find_max_slice',
                                                                                 'fastMONAI/vision_plot.py'),
                                       'fastMONAI.vision_plot.show_med_img': ('vision_plot.html#show_med_img', 'fastMONAI/vision_plot.py'),
                                       'fastMONAI.vision_plot.validate_anatomical_plane': ( 'vision_plot.html#validate_anatomical_plane',
                                                                                            'fastMONAI/vision_plot.py')}}}
